scoretools.PerformerInventory
=============================

.. inheritance-diagram:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory
   :private-bases:

.. autoclass:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.name

    Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

Methods
-------

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.append

    Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.count

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.extend

    Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.index

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.insert

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.pop

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.remove

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.reverse

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.sort

    Inherited from :py:class:`__builtin__.list`

Special Methods
---------------

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__add__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__contains__

    Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__delitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__delslice__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__eq__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__ge__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__getitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__getslice__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__gt__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__iadd__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__imul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__iter__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__le__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__len__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__lt__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__mul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__ne__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__repr__

    Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__reversed__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__rmul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__setitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__setslice__

    Inherited from :py:class:`__builtin__.list`
